==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/runtime/Clib/ceval.c <==
/* --------------------------------------------------------------------*/
/*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
/*                                                                     */
/*                                     ,--^,                           */
/*                               _ ___/ /|/                            */
/*                           ,;'( )__, ) '                             */
/*                          ;;  //   L__.                              */
/*                          '   \   /  '                               */
/*                               ^   ^                                 */
/*                                                                     */
/*                                                                     */
/*    This program is distributed in the hope that it will be useful.  */
/*    Use and copying of this software and preparation of derivative   */
/*    works based upon this software are permitted, so long as the     */
/*    following conditions are met:                                    */
/*           o credit to the authors is acknowledged following         */
/*             current academic behaviour                              */
/*           o no fees or compensation are charged for use, copies,    */
/*             or access to this software                              */
/*           o this copyright notice is included intact.               */
/*      This software is made available AS IS, and no warranty is made */
/*      about the software or its performance.                         */
/*                                                                     */
/*      Bug descriptions, use reports, comments or suggestions are     */
/*      welcome. Send them to                                          */
/*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
/*-------------------------------------------------------------------- */
/*=====================================================================*/
/*    serrano/prgm/project/bigloo/runtime1.8/Clib/eval.c               */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Fri Sep 24 10:20:30 1993                          */
/*    Last change :  Tue May 16 13:50:34 1995 (serrano)                */
/*    -------------------------------------------------------------    */
/*    Quelques petites fonctions pour l'interprete (principalement     */
/*    des fonctions de debug et de trace)                              */
/*=====================================================================*/
#include <bigloo1.9c.h>

/*---------------------------------------------------------------------*/
/*    Des variables de controle                                        */
/*---------------------------------------------------------------------*/
static obj_t eval_name, wrong_number, not_a_proc;

/*---------------------------------------------------------------------*/
/*    Une recup ...                                                    */
/*---------------------------------------------------------------------*/
extern long  list_length();
extern obj_t string_to_bstring();

/*---------------------------------------------------------------------*/
/*    void                                                             */
/*    init_eval_cnst ...                                               */
/*---------------------------------------------------------------------*/
void
init_eval_cnst()
{
   eval_name    = string_to_bstring( "eval" );
   wrong_number = string_to_bstring( "wrong number of argument for" );
   not_a_proc   = string_to_bstring( "Not a procedure" );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_0 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_0( name, fun )
obj_t name, fun;
{
   if( PROCEDUREP( fun ) )
   {
      if( PROCEDURE_CORRECT_ARITYP( fun, 0 ) )
         return PROCEDURE_ENTRY( fun )( fun, BEOA );
      else
         FAILURE( eval_name, wrong_number, name );
   }
   else
      FAILURE( eval_name, not_a_proc, name );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_1 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_1( name, fun, a0 )
obj_t name, fun, a0;
{
   if( PROCEDUREP( fun ) )
   {
      if( PROCEDURE_CORRECT_ARITYP( fun, 1 ) )
         return PROCEDURE_ENTRY( fun )( fun, a0, BEOA );
      else
         FAILURE( eval_name, wrong_number, name );
   }
   else
      FAILURE( eval_name, not_a_proc, name );
}
       
/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_2 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_2( name, fun, a0, a1 )
obj_t name, fun, a0, a1;
{
   if( PROCEDUREP( fun ) )
   {
      if( PROCEDURE_CORRECT_ARITYP( fun, 2 ) )
         return PROCEDURE_ENTRY( fun )( fun, a0, a1, BEOA );
      else
         FAILURE( eval_name, wrong_number, name );
   }
   else
      FAILURE( eval_name, not_a_proc, name );
}
       
/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_3 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_3( name, fun, a0, a1, a2 )
obj_t name, fun, a0, a1, a2;
{
   if( PROCEDUREP( fun ) )
   {
      if( PROCEDURE_CORRECT_ARITYP( fun, 3 ) )
         return PROCEDURE_ENTRY( fun )( fun, a0, a1, a2, BEOA );
      else
         FAILURE( eval_name, wrong_number, name );
   }
   else
      FAILURE( eval_name, not_a_proc, name );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_4 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_4( name, fun, a0, a1, a2, a3 )
obj_t name, fun, a0, a1, a2, a3;
{
   if( PROCEDUREP( fun ) )
   {
      if( PROCEDURE_CORRECT_ARITYP( fun, 4 ) )
         return PROCEDURE_ENTRY( fun )( fun, a0, a1, a2, a3, BEOA );
      else
         FAILURE( eval_name, wrong_number, name );
   }
   else
      FAILURE( eval_name, not_a_proc, name );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    eval_apply ...                                                   */
/*---------------------------------------------------------------------*/
obj_t
eval_apply( name, fun, list )
obj_t name, fun, list;
{
   if( PROCEDUREP( fun ) )
   {
      long len = list_length( list );

      if( PROCEDURE_CORRECT_ARITYP( fun, len ) )
         return apply( fun, list );
      else
         FAILURE( eval_name, wrong_number, name );
   }
   else
      FAILURE( eval_name, not_a_proc, name );
}

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/runtime/Clib/ceval.c <==
/*=====================================================================*/
/*    serrano/prgm/project/bigloo/runtime/Clib/ceval.c                 */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Fri Sep 24 10:20:30 1993                          */
/*    Last change :  Mon Jul 31 09:33:21 2006 (serrano)                */
/*    -------------------------------------------------------------    */
/*    Quelques petites fonctions pour l'interprete (principalement     */
/*    des fonctions de debug et de trace)                              */
/*=====================================================================*/
#include <bigloo.h>

/*---------------------------------------------------------------------*/
/*    void                                                             */
/*    bgl_init_eval_cnst ...                                           */
/*---------------------------------------------------------------------*/
void
bgl_init_eval_cnst() {
   ;
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_0 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_0( obj_t fun ) {
   return PROCEDURE_ENTRY( fun )( fun, BEOA );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_1 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_1( obj_t fun, obj_t a0 ) {
   return PROCEDURE_ENTRY( fun )( fun, a0, BEOA );
}
       
/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_2 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_2( obj_t fun, obj_t a0, obj_t a1 ) {
   return PROCEDURE_ENTRY( fun )( fun, a0, a1, BEOA );
}
       
/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_3 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_3( obj_t fun, obj_t a0, obj_t a1, obj_t a2 ) {
   return PROCEDURE_ENTRY( fun )( fun, a0, a1, a2, BEOA );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    funcall_4 ...                                                    */
/*---------------------------------------------------------------------*/
obj_t
eval_funcall_4( obj_t fun, obj_t a0, obj_t a1, obj_t a2, obj_t a3 ) {
   return PROCEDURE_ENTRY( fun )( fun, a0, a1, a2, a3, BEOA );
}

/*---------------------------------------------------------------------*/
/*    obj_t                                                            */
/*    eval_apply ...                                                   */
/*---------------------------------------------------------------------*/
BGL_RUNTIME_DEF
obj_t
eval_apply( obj_t fun, obj_t list ) {
   return apply( fun, list );
}
